@@ -2,10 +2,10 @@
 """
 
 import yaml
-
-from src.decommissioned.guaussian_polynoms import interpolate, generate_polynomial, solve
 import src.decommissioned.guaussian_polynoms as package
-from tests.suite import run_on
+from src.decommissioned.guaussian_polynoms import (generate_polynomial,
+                                                   interpolate, solve)
+from tests.secret_splitter.suite import run_on
 
 SIZE = 128
 
